@@ -536,7 +536,11 @@ static int __kcapi load_ware (struct capi_ctr * ctrl, capiloaddata * ware) {
 		return stack_init (ctx->dev);
 	}
 	ERROR("Firmware does not respond!\n");
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,31)
+	capi_ctr_down (ctrl);
+#else
 	capi_ctr_reseted (ctrl);
+#endif
 	return -EBUSY;
 #else
 	UNUSED_ARG (ctrl);
@@ -1282,10 +1286,14 @@ void kill_thread (void) {
 
 	if (thread_pid != -1) {
 		atomic_set (&thread_run_flag, 0);
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,25)  
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,30)
+		if (NULL == pid_task ( find_vpid(thread_pid), PIDTYPE_PID )) {
+#else
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,25)
 		if (NULL == find_task_by_vpid (thread_pid)) {
 #else
 		if (NULL == find_task_by_pid (thread_pid)) {
+#endif
 #endif
 			LOG("Thread[%d] has died before!\n", thread_pid);
 		} else {
