@@ -1,23 +1,25 @@
 /* 
  * main.c
+ * 
  * Copyright (C) 2002, AVM GmbH. All rights reserved.
  * 
- * This Software is  free software. You can redistribute and/or
- * modify such free software under the terms of the GNU Lesser General Public
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
  * 
- * The free software is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * Lesser General Public License for more details.
  * 
  * You should have received a copy of the GNU Lesser General Public
- * License along with this Software; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA, or see
- * http://www.opensource.org/licenses/lgpl-license.html
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301  USA
  * 
- * Contact: AVM GmbH, Alt-Moabit 95, 10559 Berlin, Germany, email: info@avm.de
+ * Contact:
+ *   AVM GmbH, Alt-Moabit 95, 10559 Berlin, Germany, email: info@avm.de
  */
 
 #include <linux/kernel.h>
@@ -67,7 +69,14 @@
 
 /*---------------------------------------------------------------------------*\
 \*---------------------------------------------------------------------------*/
-MODULE_LICENSE ("Proprietary");
+/* 
+ * about proprietarity of kernel modules:
+ * Similar case as for ndiswrapper can be found for fcusb/fcusb2 module.
+ * It have two parts, one is the firmware, which is non-GPL, and the API
+ * of the module, which have a LGPL 2.1 license. Since version 0.8.1 the
+ * module license is now set to GPL.
+ */
+MODULE_LICENSE ("GPL");
 MODULE_DESCRIPTION ("CAPI4Linux: Driver for " PRODUCT_LOGO);
 
 /*---------------------------------------------------------------------------*\
@@ -324,7 +333,7 @@ static int __init usb_init (void) {
 	NOTE("-- 32 bit CAPI driver --\n");
 #endif
 
-	NOTE("Loading...\n");
+	NOTE("Loading firmware ...\n");
 	if (0 != (urr = usb_register (&usb_driver))) {
 		ERROR("Failed to register USB driver! (%d)\n", urr);
 		goto exit;
@@ -342,7 +351,7 @@ static void __exit usb_exit (void) {
 #ifndef NDEBUG
 	unsigned u;
 #endif
-	NOTE("Removing...\n");
+	NOTE("Removing firmware ...\n");
 	kill_thread ();
 	unregister_capi_driver (&usb_capi_driver);
 	usb_deregister (&usb_driver);
